# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint
import six


class SmoothStreamingRepresentation(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 encoding_id=None,
                 muxing_id=None,
                 media_file=None,
                 language=None,
                 track_name=None,
                 priority=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, string_types, string_types, string_types, string_types, int) -> None
        super(SmoothStreamingRepresentation, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._encoding_id = None
        self._muxing_id = None
        self._media_file = None
        self._language = None
        self._track_name = None
        self._priority = None
        self.discriminator = None

        if encoding_id is not None:
            self.encoding_id = encoding_id
        if muxing_id is not None:
            self.muxing_id = muxing_id
        if media_file is not None:
            self.media_file = media_file
        if language is not None:
            self.language = language
        if track_name is not None:
            self.track_name = track_name
        if priority is not None:
            self.priority = priority

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(SmoothStreamingRepresentation, self), 'openapi_types'):
            types = getattr(super(SmoothStreamingRepresentation, self), 'openapi_types')

        types.update({
            'encoding_id': 'string_types',
            'muxing_id': 'string_types',
            'media_file': 'string_types',
            'language': 'string_types',
            'track_name': 'string_types',
            'priority': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(SmoothStreamingRepresentation, self), 'attribute_map'):
            attributes = getattr(super(SmoothStreamingRepresentation, self), 'attribute_map')

        attributes.update({
            'encoding_id': 'encodingId',
            'muxing_id': 'muxingId',
            'media_file': 'mediaFile',
            'language': 'language',
            'track_name': 'trackName',
            'priority': 'priority'
        })
        return attributes

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this SmoothStreamingRepresentation.

        Id of the encoding (required)

        :return: The encoding_id of this SmoothStreamingRepresentation.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this SmoothStreamingRepresentation.

        Id of the encoding (required)

        :param encoding_id: The encoding_id of this SmoothStreamingRepresentation.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def muxing_id(self):
        # type: () -> string_types
        """Gets the muxing_id of this SmoothStreamingRepresentation.

        Id of the muxing. (required)

        :return: The muxing_id of this SmoothStreamingRepresentation.
        :rtype: string_types
        """
        return self._muxing_id

    @muxing_id.setter
    def muxing_id(self, muxing_id):
        # type: (string_types) -> None
        """Sets the muxing_id of this SmoothStreamingRepresentation.

        Id of the muxing. (required)

        :param muxing_id: The muxing_id of this SmoothStreamingRepresentation.
        :type: string_types
        """

        if muxing_id is not None:
            if not isinstance(muxing_id, string_types):
                raise TypeError("Invalid type for `muxing_id`, type has to be `string_types`")

        self._muxing_id = muxing_id

    @property
    def media_file(self):
        # type: () -> string_types
        """Gets the media_file of this SmoothStreamingRepresentation.

        The Smooth Streaming ismv or isma file that will be referenced in the manifest. (required)

        :return: The media_file of this SmoothStreamingRepresentation.
        :rtype: string_types
        """
        return self._media_file

    @media_file.setter
    def media_file(self, media_file):
        # type: (string_types) -> None
        """Sets the media_file of this SmoothStreamingRepresentation.

        The Smooth Streaming ismv or isma file that will be referenced in the manifest. (required)

        :param media_file: The media_file of this SmoothStreamingRepresentation.
        :type: string_types
        """

        if media_file is not None:
            if not isinstance(media_file, string_types):
                raise TypeError("Invalid type for `media_file`, type has to be `string_types`")

        self._media_file = media_file

    @property
    def language(self):
        # type: () -> string_types
        """Gets the language of this SmoothStreamingRepresentation.

        Language of the MP4 file

        :return: The language of this SmoothStreamingRepresentation.
        :rtype: string_types
        """
        return self._language

    @language.setter
    def language(self, language):
        # type: (string_types) -> None
        """Sets the language of this SmoothStreamingRepresentation.

        Language of the MP4 file

        :param language: The language of this SmoothStreamingRepresentation.
        :type: string_types
        """

        if language is not None:
            if not isinstance(language, string_types):
                raise TypeError("Invalid type for `language`, type has to be `string_types`")

        self._language = language

    @property
    def track_name(self):
        # type: () -> string_types
        """Gets the track_name of this SmoothStreamingRepresentation.

        Track where this MP4 shoudl be added

        :return: The track_name of this SmoothStreamingRepresentation.
        :rtype: string_types
        """
        return self._track_name

    @track_name.setter
    def track_name(self, track_name):
        # type: (string_types) -> None
        """Sets the track_name of this SmoothStreamingRepresentation.

        Track where this MP4 shoudl be added

        :param track_name: The track_name of this SmoothStreamingRepresentation.
        :type: string_types
        """

        if track_name is not None:
            if not isinstance(track_name, string_types):
                raise TypeError("Invalid type for `track_name`, type has to be `string_types`")

        self._track_name = track_name

    @property
    def priority(self):
        # type: () -> int
        """Gets the priority of this SmoothStreamingRepresentation.

        Specify the priority of this representation. Representations with higher priority will be listed first in the manifest.

        :return: The priority of this SmoothStreamingRepresentation.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        # type: (int) -> None
        """Sets the priority of this SmoothStreamingRepresentation.

        Specify the priority of this representation. Representations with higher priority will be listed first in the manifest.

        :param priority: The priority of this SmoothStreamingRepresentation.
        :type: int
        """

        if priority is not None:
            if not isinstance(priority, int):
                raise TypeError("Invalid type for `priority`, type has to be `int`")

        self._priority = priority

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(SmoothStreamingRepresentation, self), "to_dict"):
            result = super(SmoothStreamingRepresentation, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmoothStreamingRepresentation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.mjpeg_video_configuration import MjpegVideoConfiguration
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.configurations.video.mjpeg.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.mjpeg.mjpeg_video_configuration_list_query_params import MjpegVideoConfigurationListQueryParams


class MjpegApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(MjpegApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, mjpeg_video_configuration, **kwargs):
        # type: (MjpegVideoConfiguration, dict) -> MjpegVideoConfiguration
        """Create MJPEG Codec Configuration

        :param mjpeg_video_configuration: The MJPEG Codec Configuration to be created
        :type mjpeg_video_configuration: MjpegVideoConfiguration, required
        :return: MJPEG Video Configuration
        :rtype: MjpegVideoConfiguration
        """

        return self.api_client.post(
            '/encoding/configurations/video/mjpeg',
            mjpeg_video_configuration,
            type=MjpegVideoConfiguration,
            **kwargs
        )

    def delete(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete MJPEG Codec Configuration

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: Id of the codec configuration
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/configurations/video/mjpeg/{configuration_id}',
            path_params={'configuration_id': configuration_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> MjpegVideoConfiguration
        """MJPEG Codec Configuration Details

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: MJPEG Audio Configuration
        :rtype: MjpegVideoConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations/video/mjpeg/{configuration_id}',
            path_params={'configuration_id': configuration_id},
            type=MjpegVideoConfiguration,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (MjpegVideoConfigurationListQueryParams, dict) -> MjpegVideoConfiguration
        """List MJPEG Configurations

        :param query_params: Query parameters
        :type query_params: MjpegVideoConfigurationListQueryParams
        :return: List of MJPEG codec configurations
        :rtype: MjpegVideoConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations/video/mjpeg',
            query_params=query_params,
            pagination_response=True,
            type=MjpegVideoConfiguration,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.ad_analytics_attribute import AdAnalyticsAttribute
from bitmovin_api_sdk.models.ad_analytics_query_request import AdAnalyticsQueryRequest
from bitmovin_api_sdk.models.analytics_interval import AnalyticsInterval
import pprint
import six


class AdAnalyticsPercentileQueryRequest(AdAnalyticsQueryRequest):
    @poscheck_model
    def __init__(self,
                 start=None,
                 end=None,
                 license_key=None,
                 filters=None,
                 order_by=None,
                 dimension=None,
                 interval=None,
                 group_by=None,
                 limit=None,
                 offset=None,
                 percentile=None):
        # type: (datetime, datetime, string_types, list[AdAnalyticsAbstractFilter], list[AdAnalyticsOrderByEntry], AdAnalyticsAttribute, AnalyticsInterval, list[AdAnalyticsAttribute], int, int, int) -> None
        super(AdAnalyticsPercentileQueryRequest, self).__init__(start=start, end=end, license_key=license_key, filters=filters, order_by=order_by, dimension=dimension, interval=interval, group_by=group_by, limit=limit, offset=offset)

        self._percentile = None
        self.discriminator = None

        if percentile is not None:
            self.percentile = percentile

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AdAnalyticsPercentileQueryRequest, self), 'openapi_types'):
            types = getattr(super(AdAnalyticsPercentileQueryRequest, self), 'openapi_types')

        types.update({
            'percentile': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AdAnalyticsPercentileQueryRequest, self), 'attribute_map'):
            attributes = getattr(super(AdAnalyticsPercentileQueryRequest, self), 'attribute_map')

        attributes.update({
            'percentile': 'percentile'
        })
        return attributes

    @property
    def percentile(self):
        # type: () -> int
        """Gets the percentile of this AdAnalyticsPercentileQueryRequest.

        The percentage (0-99) used for percentile queries.

        :return: The percentile of this AdAnalyticsPercentileQueryRequest.
        :rtype: int
        """
        return self._percentile

    @percentile.setter
    def percentile(self, percentile):
        # type: (int) -> None
        """Sets the percentile of this AdAnalyticsPercentileQueryRequest.

        The percentage (0-99) used for percentile queries.

        :param percentile: The percentile of this AdAnalyticsPercentileQueryRequest.
        :type: int
        """

        if percentile is not None:
            if not isinstance(percentile, int):
                raise TypeError("Invalid type for `percentile`, type has to be `int`")

        self._percentile = percentile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AdAnalyticsPercentileQueryRequest, self), "to_dict"):
            result = super(AdAnalyticsPercentileQueryRequest, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdAnalyticsPercentileQueryRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.audio_mix_input_stream import AudioMixInputStream
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.input_streams.audio_mix.audio_mix_input_stream_list_query_params import AudioMixInputStreamListQueryParams


class AudioMixApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AudioMixApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, audio_mix_input_stream, **kwargs):
        # type: (string_types, AudioMixInputStream, dict) -> AudioMixInputStream
        """Add audio mix input stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param audio_mix_input_stream: The audio mix input stream to be created
        :type audio_mix_input_stream: AudioMixInputStream, required
        :return: Audio mix input stream
        :rtype: AudioMixInputStream
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/input-streams/audio-mix',
            audio_mix_input_stream,
            path_params={'encoding_id': encoding_id},
            type=AudioMixInputStream,
            **kwargs
        )

    def delete(self, encoding_id, input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete audio mix input stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param input_stream_id: Id of the audio mix input stream.
        :type input_stream_id: string_types, required
        :return: Id of the audio mix input stream
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/input-streams/audio-mix/{input_stream_id}',
            path_params={'encoding_id': encoding_id, 'input_stream_id': input_stream_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> AudioMixInputStream
        """Audio mix input stream details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param input_stream_id: Id of the audio mix input stream.
        :type input_stream_id: string_types, required
        :return: Stream
        :rtype: AudioMixInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/audio-mix/{input_stream_id}',
            path_params={'encoding_id': encoding_id, 'input_stream_id': input_stream_id},
            type=AudioMixInputStream,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, AudioMixInputStreamListQueryParams, dict) -> AudioMixInputStream
        """List audio mix input stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: AudioMixInputStreamListQueryParams
        :return: List of audio mix input stream
        :rtype: AudioMixInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/audio-mix',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=AudioMixInputStream,
            **kwargs
        )
